# mama-fleury2

Esse repositório procura seguir o padrão [Cookiecutter Data Science](https://drivendata.github.io/cookiecutter-data-science/), com pequenos ajustes para o caso particular. 

Para rodar os notebooks em sequência (ordem alfabética) basta usar o comando:

```
jupyter nbconvert --inplace --execute *.ipynb
```